==> GreggSchofield_cdk_construct_library-0.0.10-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### PlatformQueue <a name="PlatformQueue" id="cdk-construct-library.PlatformQueue"></a>

#### Initializers <a name="Initializers" id="cdk-construct-library.PlatformQueue.Initializer"></a>

```typescript
import { PlatformQueue } from 'cdk-construct-library'

new PlatformQueue(scope: Construct, id: string)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk-construct-library.PlatformQueue.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk-construct-library.PlatformQueue.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk-construct-library.PlatformQueue.Initializer.parameter.id"></a>

- *Type:* string

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="cdk-construct-library.PlatformQueue.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="cdk-construct-library.PlatformQueue.isConstruct"></a>

```typescript
import { PlatformQueue } from 'cdk-construct-library'

PlatformQueue.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="cdk-construct-library.PlatformQueue.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk-construct-library.PlatformQueue.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

==> GreggSchofield_cdk_construct_library-0.0.15-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### PlatformQueue <a name="PlatformQueue" id="cdk-construct-library.PlatformQueue"></a>

#### Initializers <a name="Initializers" id="cdk-construct-library.PlatformQueue.Initializer"></a>

```typescript
import { PlatformQueue } from 'cdk-construct-library'

new PlatformQueue(scope: Construct, id: string, props: PlatformQueueProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#cdk-construct-library.PlatformQueue.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#cdk-construct-library.PlatformQueue.Initializer.parameter.props">props</a></code> | <code><a href="#cdk-construct-library.PlatformQueueProps">PlatformQueueProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="cdk-construct-library.PlatformQueue.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="cdk-construct-library.PlatformQueue.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="cdk-construct-library.PlatformQueue.Initializer.parameter.props"></a>

- *Type:* <a href="#cdk-construct-library.PlatformQueueProps">PlatformQueueProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="cdk-construct-library.PlatformQueue.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="cdk-construct-library.PlatformQueue.isConstruct"></a>

```typescript
import { PlatformQueue } from 'cdk-construct-library'

PlatformQueue.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="cdk-construct-library.PlatformQueue.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueue.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="cdk-construct-library.PlatformQueue.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


## Structs <a name="Structs" id="Structs"></a>

### PlatformQueueProps <a name="PlatformQueueProps" id="cdk-construct-library.PlatformQueueProps"></a>

#### Initializer <a name="Initializer" id="cdk-construct-library.PlatformQueueProps.Initializer"></a>

```typescript
import { PlatformQueueProps } from 'cdk-construct-library'

const platformQueueProps: PlatformQueueProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#cdk-construct-library.PlatformQueueProps.property.dlq">dlq</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#cdk-construct-library.PlatformQueueProps.property.fifo">fifo</a></code> | <code>boolean</code> | *No description.* |

---

##### `dlq`<sup>Optional</sup> <a name="dlq" id="cdk-construct-library.PlatformQueueProps.property.dlq"></a>

```typescript
public readonly dlq: boolean;
```

- *Type:* boolean

---

##### `fifo`<sup>Optional</sup> <a name="fifo" id="cdk-construct-library.PlatformQueueProps.property.fifo"></a>

```typescript
public readonly fifo: boolean;
```

- *Type:* boolean

---
